@@ -132,13 +132,21 @@ class AbstractDnsZoneBuilder(abc.ABC):
             self.resource_record[domain][rr_type] = []
         self.resource_record[domain][rr_type].append((ttl, values))
 
-    def add_soa_rr(self, mname, rname_email, serial=None, refresh=86400, retry=7200, expire=3600000, ttl=3600):
+    def add_soa_rr(self, mname, rname_email, serial=None, refresh=None, retry=None, expire=None, ttl=None):
         if self.has_rr_record(self.origin, "SOA"):
             raise DuplicateSoaException
         (local, domain) = rname_email.split("@")
         rname = ".".join((local.replace(".", "\\."), domain, ""))
         if serial is None:
             serial = self.default_serial()
+        if refresh is None:
+            refresh = 86400
+        if retry is None:
+            retry = 7200
+        if expire is None:
+            expire = 3600000
+        if ttl is None:
+            ttl=3600
         if retry >= refresh:
             retry = refresh - 1
         if expire <= refresh + retry:
@@ -162,7 +170,7 @@ class DnsZoneBuilder(AbstractDnsZoneBuilder):
         self.reverse_zones = [ReverseDnsZoneBuilder(ro, ttl) for ro in reverse_origins]
         super().__init__(origin, ttl)
 
-    def add_soa_rr(self, mname, rname_email, serial=None, refresh=86400, retry=7200, expire=3600000, ttl=172800):
+    def add_soa_rr(self, mname, rname_email, serial=None, refresh=None, retry=None, expire=None, ttl=None):
         super().add_soa_rr(mname, rname_email, serial, refresh, retry, expire, ttl)
         for rz in self.reverse_zones:
             rz.add_soa_rr(mname, rname_email, serial, refresh, retry, expire, ttl)
@@ -230,7 +238,7 @@ if __name__ == "__main__":
 
     dzb = DnsZoneBuilder("example.com", 3600, ("10.0.0.0/16", "fd00:feed:dead:beef::/64"))
 
-    dzb.add_soa_rr("dns.example.com.", "john.doe@example.com")
+    dzb.add_soa_rr("dns.example.com.", "john.doe@example.com", None, 900, 900, 900)
     dzb.add_ns_rr("@", "dns.example.com.")
     dzb.add_ns_rr("@", "dnssec.example.com.")
     dzb.add_spf_rr("@", "v=spf1 ip4:10.0.0.0/16 ip6:fd00:feed:dead:beef::/64 -all")
